copra package
=============

Submodules
----------

copra.rest module
-----------------

.. automodule:: copra.rest
    :members:
    :undoc-members:
    :show-inheritance:

copra.websocket module
----------------------

.. automodule:: copra.websocket
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: copra
    :members:
    :undoc-members:
    :show-inheritance:
